@@ -138,11 +138,11 @@ process_layers <- function(g, z, gt, gf, interactive) {
 	
 	# fill info
 	if (is.null(g$tm_fill)) {
-		gfill <- list(fill=NULL, xfill=NA, fill.legend.title=NA, fill.id=NA, fill.group = NA) 
+		fill.group <- if (is.null(g$tm_borders)) NA else g$tm_borders$group
+		gfill <- list(fill=NULL, xfill=NA, fill.legend.title=NA, fill.id=NA, fill.group = fill.group) 
 	} else {
 		g$tm_fill$gborders <- gborders
 		gfill <- process_fill(data, g$tm_fill, gt, gf, z=z+which(plot.order=="tm_fill"), interactive=interactive)
-		gfill <<- gfill
 	}
 	# symbol info
 	if (is.null(g$tm_symbols)) {
